@@ -1,4 +1,6 @@
 package POE::Component::CPANIDX;
+$POE::Component::CPANIDX::VERSION = '0.12';
+#ABSTRACT: A POE mechanism for querying the CPANIDX
 
 use strict;
 use warnings;
@@ -7,9 +9,6 @@ use POE qw(Component::Client::HTTP);
 use YAML::Tiny;
 use HTTP::Request::Common;
 use File::Spec::Unix;
-use vars qw($VERSION);
-
-$VERSION = '0.10';
 
 my $cmds = {
   mod       => 1,
@@ -38,7 +37,6 @@ sub _free_identifier {
   delete $active_identifiers{$id};
 }
 
-
 sub spawn {
   my $package = shift;
   my %opts = @_;
@@ -197,10 +195,18 @@ qq[CAPTCH!];
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::CPANIDX - A POE mechanism for querying the CPANIDX
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   use strict;
@@ -378,18 +384,19 @@ indicating what the problem was.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 L<App::CPANIDX>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
